# PyMink - An N-Gram Based Classification Package

Pymink is currently in its early stages of development. It is intended to be a simple text classification package. I intend to implement a language and category classification. A word prediction model may also be in the grand scheme of things.

If you wish to collaborate on this start up project feel free to create a pull request to the following github link: https://github.com/fabiocfabini/pymink
